/* Test diagnostic for extra semicolon outside a function.  Test with
   no special options.  */
/* Origin: Joseph Myers <joseph@codesourcery.com> */
/* { dg-do compile } */
/* { dg-options "" } */

;
