-- AE3702A.ADA

--                             Grant of Unlimited Rights
--
--     Under contracts F33600-87-D-0337, F33600-84-D-0280, MDA903-79-C-0687,
--     F08630-91-C-0015, and DCA100-97-D-0025, the U.S. Government obtained 
--     unlimited rights in the software and documentation contained herein.
--     Unlimited rights are defined in DFAR 252.227-7013(a)(19).  By making 
--     this public release, the Government intends to confer upon all 
--     recipients unlimited rights  equal to those held by the Government.  
--     These rights include rights to use, duplicate, release or disclose the 
--     released technical data and computer software in whole or in part, in 
--     any manner and for any purpose whatsoever, and to have or permit others 
--     to do so.
--
--                                    DISCLAIMER
--
--     ALL MATERIALS OR INFORMATION HEREIN RELEASED, MADE AVAILABLE OR
--     DISCLOSED ARE AS IS.  THE GOVERNMENT MAKES NO EXPRESS OR IMPLIED 
--     WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING THE CONDITIONS OF THE
--     SOFTWARE, DOCUMENTATION OR OTHER INFORMATION RELEASED, MADE AVAILABLE 
--     OR DISCLOSED, OR THE OWNERSHIP, MERCHANTABILITY, OR FITNESS FOR A
--     PARTICULAR PURPOSE OF SAID MATERIAL.
--*
-- CHECK THAT INTEGER_IO CAN BE INSTANTIATED FOR USER DEFINED INTEGER
-- TYPES.

-- SPS 10/1/82

WITH REPORT; USE REPORT;
WITH TEXT_IO; USE TEXT_IO;

PROCEDURE AE3702A IS
BEGIN

     TEST ("AE3702A", "CHECK THAT INTEGER_IO CAN BE INSTANTIATED FOR " &
                      "USER DEFINED TYPES");

     DECLARE
          TYPE I1 IS RANGE 6 .. 14;
          TYPE I2 IS NEW INTEGER;
          TYPE I3 IS NEW INTEGER RANGE 0 .. INTEGER'LAST;
          SUBTYPE S1 IS INTEGER RANGE 6 .. 14;
          SUBTYPE S2 IS INTEGER;
          SUBTYPE S3 IS INTEGER RANGE 0 .. INTEGER'LAST;

          PACKAGE NIO1 IS NEW INTEGER_IO (I1);
          PACKAGE NIO2 IS NEW INTEGER_IO (I2);
          PACKAGE NIO3 IS NEW INTEGER_IO (I3);
          PACKAGE NIO4 IS NEW INTEGER_IO (S1);
          PACKAGE NIO5 IS NEW INTEGER_IO (S2);
          PACKAGE NIO6 IS NEW INTEGER_IO (S3);

     BEGIN
          NULL;
     END;

     RESULT;
END AE3702A;
